{% extends "admin/change_form.html" %}
{% load i18n whatsnew %}


{% block object-tools-items %}
  <li><a href="{% url 'whatsnew-test' %}" class="whatsnew-preview">{% trans "Preview" %}</a></li>
  {{ block.super }}
{% endblock %}
