{% extends "base.html" %}{% load whatsnew %}

{% block body %}
    {% whatsnew 'whatsnew' 1 %}
    <script>
        $('.b-close').click(function () {
             window.history.go(-1);
        })

    </script>
{% endblock body %}
{% block jira %}{% endblock jira %}
